@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
  */
 
 #ifndef _SUBVERTPY_UTIL_H_
@@ -34,11 +34,6 @@
 
 #define ONLY_BEFORE_SVN(maj, min) (!(ONLY_SINCE_SVN(maj, min)))
 
-/* There's no Py_ssize_t in 2.4, apparently */
-#if PY_MAJOR_VERSION == 2 && PY_MINOR_VERSION < 5
-typedef int Py_ssize_t;
-#endif
-
 #ifdef __GNUC__
 #pragma GCC visibility push(hidden)
 #endif
@@ -124,6 +119,12 @@ typedef enum svn_depth_t {
 } svn_depth_t;
 #endif
 
+typedef struct {
+    PyObject_HEAD
+    apr_hash_t *config;
+    apr_pool_t *pool;
+} ConfigObject;
+
 typedef struct {
 	PyObject_HEAD
 	svn_stream_t *stream;
